"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const graphql_1 = require("graphql");
const error_1 = require("graphql/error");
const language_1 = require("graphql/language");
const timePortion = (d) => (d.toJSON() || "").slice(11, 8);
const serialize = (value) => {
    // must be a date or string
    switch (typeof value) {
        case "string":
            const m = value.match(/^([0-9]{2}):([0-9]{2}):([0-9]{2})$/);
            if (!m) {
                throw new TypeError(`value is not a valid time string 'hh:mm:ss'`);
            }
            if (value !== timePortion(new Date(`1970-01-01T${value}Z`))) {
                throw new TypeError(`value is an invalid time: ${value}`);
            }
            return value;
        default:
            if (value instanceof Date) {
                if (Number.isNaN(value.getTime())) {
                    throw new TypeError(`Value is not a valid Date: ${value}`);
                }
                return timePortion(value);
            }
            throw new TypeError(`Value is not an instance of Date or string: ${value}`);
    }
};
const parseLiteral = ast => {
    if (ast.kind !== language_1.Kind.STRING) {
        throw new error_1.GraphQLError(`Can only parse strings to dates but got a: ${ast.kind}`);
    }
    return serialize(ast.value);
};
exports.TimeScalar = new graphql_1.GraphQLScalarType({
    name: "Time",
    description: "time field format is 'hh:mm:ss'",
    serialize,
    parseValue: serialize,
    parseLiteral
});
//# sourceMappingURL=time.js.map